Properties Methods Events Direct Link

# Class Ext.calendar.EventRecord

Package: | Ext.calendar
Defined In: | EventRecord.js
Class: | EventRecord
Extends: | Object

This is the Record specification for calendar event data used by the CalendarPanel's underlying store. It can be overridden as necessary to customize the fields supported by events, although the existing column names should not be altered. If your model fields are named differently you should update the mapping configs accordingly.

The only required fields when creating a new event record instance are StartDate and EndDate. All other fields are either optional are will be defaulted if blank.

Here is a basic example for how to create a new record of this type:

    rec = new Ext.calendar.EventRecord({
        StartDate: '2101-01-12 12:00:00',
        EndDate: '2101-01-12 13:30:00',
        Title: 'My cool event',
        Notes: 'Some notes'
    });

If you have overridden any of the record's data mappings via the Ext.calendar.EventMappings object you may need to set the values using this alternate syntax to ensure that the fields match up correctly:

    var M = Ext.calendar.EventMappings;

    rec = new Ext.calendar.EventRecord();
    rec.data[M.StartDate.name] = '2101-01-12 12:00:00';
    rec.data[M.EndDate.name] = '2101-01-12 13:30:00';
    rec.data[M.Title.name] = 'My cool event';
    rec.data[M.Notes.name] = 'Some notes';

## Public Properties

This class has no public properties.

## Public Methods

Method | Defined By
--- | ---
| EventRecord( [`Object data`], [`Object id`] ) Parameters: `data` : Object (Optional) An object, the properties of which provide values for the new Record's fields. If not specified the defaultValue for each field will be assigned. `id` : Object (Optional) The id of the Record. The id is used by the Ext.data.Store object which owns the Record to index its collection of Records (therefore this id should be unique within each store). If an id is not specified a phantom Record will be created with an automatically generated id. Returns: void | EventRecord
| EventRecord.reconfigure() : void Reconfigures the default record definition based on the current Ext.calendar.EventMappings object Reconfigures the default record definition based on the current Ext.calendar.EventMappings object Parameters: None. Returns: void | EventRecord

## Public Events

This class has no public events.